Name: R-base
Version: 2.4.1
Release: alt1

Summary: A language for data analysis and graphics
License: GPL
Group: Sciences/Mathematics

URL: http://www.r-project.org
Source0: R-%version-%release.tar

# Automatically added by buildreq on Mon Jan 22 2007
BuildRequires: bzlib-devel gcc-c++ gcc-fortran imake libXt-devel libjpeg-devel liblapack-devel libpcre-devel libpng-devel libreadline-devel tetex-context tetex-dvips tetex-latex tk-devel xorg-cf-files

%description
R is `GNU S' - A language and environment for statistical computing
and graphics. R is similar to the award-winning S system, which was
developed at Bell Laboratories by John Chambers et al. It provides a
wide variety of statistical and graphical techniques (linear and
nonlinear modelling, statistical tests, time series analysis,
classification, clustering, ...).

R is designed as a true computer language with control-flow
constructions for iteration and alternation, and it allows users to
add additional functionality by defining new functions. For
computationally intensive tasks, C, C++ and Fortran code can be
linked and called at run time.

S is the statistician's Matlab and R is to S what Octave is to Matlab.

%prep
%setup -q -n R-%version-%release
rm src/extra/{zlib,bzip2,pcre}/*.[ch]
rm src/extra/blas/*.f src/modules/lapack/*.f

%build
%define verid 2.4
%define Rhome %_libdir/R
%define Rbindir %Rhome/bin
%define Rdocdir %_docdir/R-%verid
export	ac_cv_path_R_PDFVIEWER=gv ac_cv_path_PAGER='less -isR' \
	ac_cv_path_R_ZIPCMD=zip ac_cv_path_R_UNZIPCMD=unzip \
	ac_cv_path_R_BROWSER=url_handler.sh
%configure \
	--enable-R-shlib --with-x \
	--with-system-zlib --with-system-bzlib --with-system-pcre \
	--with-blas=-lblas --with-lapack=-llapack \
	--with-tcl-config=%_libdir/tclConfig.sh --with-tk-config=%_libdir/tkConfig.sh \
	--libdir='$(prefix)/%_lib' rincludedir='$(prefix)/include/R' \
	rdocdir='$(prefix)/share/doc/R-%verid' \
	#

%define soname libR-%verid.so.0
mkdir -p lib
ln -s %soname lib/libR.so
%make_build libR_la=%soname LIBR_LDFLAGS=-Wl,-soname=%soname
%make_build pdf info

%ifndef __buildreqs
make check
%endif

%install
%makeinstall install-pdf install-info prefix=%buildroot%_prefix libR_la=%soname
mv %buildroot%Rhome/lib/%soname %buildroot%_libdir/%soname
ln -s `relative %_libdir/%soname %Rhome/lib/libR.so` %buildroot%Rhome/lib/libR.so

ln -s `relative %Rdocdir %Rhome/doc` %buildroot%Rhome/doc
ln -s `relative %_includedir/R %Rhome/include` %buildroot%Rhome/include

cmp %buildroot%_bindir/R %buildroot%Rhome/bin/R
ln -snfv `relative %Rhome/bin/R %_bindir/R` %buildroot%_bindir/R
sed -i s:%buildroot::g %buildroot%Rhome/bin/R
fgrep -r %buildroot %buildroot && exit 1

mkdir -p %buildroot/etc/R
mv %buildroot%Rhome/etc/* %buildroot/etc/R/
rmdir %buildroot%Rhome/etc
ln -s `relative /etc/R %Rhome/etc` %buildroot%Rhome/etc

# libR is relocated, nuke LD_LIBRARY_PATH
[ -f %buildroot/etc/R/ldpaths ]
: >%buildroot/etc/R/ldpaths

mkdir -p %buildroot%_menudir
cat >%buildroot%_menudir/%name <<EOF
?package(%name): \
	needs="text" command="/usr/bin/R" \
	section="Applications/Sciences/Mathematics" \
	title="R" longtitle="R - a language for statistical computing"
EOF

# use system libtool et al
for f in libtool texi2dvi; do
	[ -f %buildroot%Rhome/bin/$f ]
	echo -e '#!/bin/sh\nexec %_bindir/'$f' "$@"' >%buildroot%Rhome/bin/$f
done

%define _perl_lib_path %Rhome/share/perl

%pre
# prune relocated directories
/bin/rm -rf %Rhome/doc/ 2>/dev/null ||:
/bin/rm -rf %Rhome/etc/ 2>/dev/null ||:

%triggerun -- R-base < 2.4.1
/bin/mv %Rhome/doc %Rhome/doc~$PPID
/bin/mv %Rhome/etc %Rhome/etc~$PPID

%triggerpostun -- R-base < 2.4.1
/bin/mv %Rhome/doc~$PPID %Rhome/doc
/bin/mv %Rhome/etc~$PPID %Rhome/etc

%post
%post_ldconfig
%update_menus

%postun
%postun_ldconfig
%clean_menus

%files
	%_bindir/R
	%_libdir/libR*
	%_man1dir/R.*
	%_menudir/*

%dir	%Rhome

%dir	%Rbindir
	%Rbindir/BATCH
	%Rbindir/R
	%Rbindir/Rcmd
	%Rbindir/Rd2dvi
	%Rbindir/Rd2txt
	%Rbindir/Rdconv
	%Rbindir/Rprof
	%Rbindir/Sd2Rd
	%Rbindir/pager
	%Rbindir/Stangle
	%Rbindir/Sweave
	%Rbindir/javareconf

%dir	%Rbindir/exec
	%Rbindir/exec/R

%dir	/etc/R
%config(noreplace) /etc/R/*
	%Rhome/etc

%define R_library_path %Rhome/library
%dir	%R_library_path
%doc	%R_library_path/R.css

%define R_library() \
%dir	%R_library_path/%1 \
	%R_library_path/%1/* \
%doc	%R_library_path/%1/man \
%doc	%R_library_path/%1/html \
%doc	%R_library_path/%1/latex \
#doc	%R_library_path/%1/help \
	#

# Priority: base
	%R_library base
	%R_library datasets
	%R_library grDevices
	%R_library graphics
	%R_library grid
	%R_library methods
	%R_library splines
	%R_library stats
	%R_library stats4
	%R_library tools
	%R_library utils
# Priority: recommended
	%R_library KernSmooth
	%R_library MASS
	%R_library boot
	%R_library class
	%R_library cluster
	%R_library foreign
	%R_library lattice
	%R_library mgcv
	%R_library nlme
	%R_library nnet
	%R_library rpart
	%R_library spatial
	%R_library survival

%dir	%Rhome/modules
	%Rhome/modules/*.so*
%dir	%Rhome/share
	%Rhome/share/*

%dir	%Rdocdir
%doc	%Rdocdir/[A-Z]*
%exclude %Rdocdir/COPYING*
	%Rhome/doc

%package -n R-devel
Summary: Development files for the R Statistical Environment
Group: Development/Other
PreReq: R-base = %version-%release

%description -n R-devel
R is `GNU S' - A language and environment for statistical computing
and graphics. R is similar to the award-winning S system, which was
developed at Bell Laboratories by John Chambers et al. It provides a
wide variety of statistical and graphical techniques (linear and
nonlinear modelling, statistical tests, time series analysis,
classification, clustering, ...).

%files -n R-devel
%dir	%Rbindir
	%Rbindir/COMPILE
	%Rbindir/INSTALL
	%Rbindir/LINK
	%Rbindir/REMOVE
	%Rbindir/Rdiff
	%Rbindir/SHLIB
	%Rbindir/build
	%Rbindir/check
	%Rbindir/config
	%Rbindir/f77_f2c
	%Rbindir/libtool
	%Rbindir/mkinstalldirs
	%Rbindir/texi2dvi

%dir	%_includedir/R
	%_includedir/R/*.h
%dir	%_includedir/R/R_ext
	%_includedir/R/R_ext/*.h
	%Rhome/include

%dir	%Rhome
%dir	%Rhome/lib
	%Rhome/lib/libR.so

%package -n R-tcltk
Summary: Tcl/Tk Interface for the R Statistical Environment
Group: Sciences/Mathematics
Requires: R-base = %version-%release

%description -n R-tcltk
R is `GNU S' - A language and environment for statistical computing
and graphics. R is similar to the award-winning S system, which was
developed at Bell Laboratories by John Chambers et al. It provides a
wide variety of statistical and graphical techniques (linear and
nonlinear modelling, statistical tests, time series analysis,
classification, clustering, ...).

This package provides access to the platform-independent Tcl scripting
language and Tk GUI elements.

%files -n R-tcltk
%add_tcl_lib_path %R_library_path/tcltk
%dir	%R_library_path
	%R_library tcltk

%package -n R-doc-html
Summary: HTML manuals for the R Statistical Environment
Group: Sciences/Mathematics
Requires: R-base = %version-%release

%description -n R-doc-html
R is `GNU S' - A language and environment for statistical computing
and graphics. R is similar to the award-winning S system, which was
developed at Bell Laboratories by John Chambers et al. It provides a
wide variety of statistical and graphical techniques (linear and
nonlinear modelling, statistical tests, time series analysis,
classification, clustering, ...).

%files -n R-doc-html
%dir	%Rdocdir
%dir	%Rdocdir/html/
%doc	%Rdocdir/html/*
%dir	%Rdocdir/manual/
%doc	%Rdocdir/manual/*.html

%package -n R-doc-pdf
Summary: PDF manuals for the R Statistical Environment
Group: Sciences/Mathematics
Conflicts: R-base > %version, R-base < %version

%description -n R-doc-pdf
R is `GNU S' - A language and environment for statistical computing
and graphics. R is similar to the award-winning S system, which was
developed at Bell Laboratories by John Chambers et al. It provides a
wide variety of statistical and graphical techniques (linear and
nonlinear modelling, statistical tests, time series analysis,
classification, clustering, ...).

%files -n R-doc-pdf
%dir	%Rdocdir/manual/
%doc	%Rdocdir/manual/*.pdf

%package -n R-doc-info
Summary: Info manuals for the R Statistical Environment
Group: Sciences/Mathematics
Conflicts: R-base > %version, R-base < %version
Requires(post): %install_info
Requires(preun): %uninstall_info

%description -n R-doc-info
R is `GNU S' - A language and environment for statistical computing
and graphics. R is similar to the award-winning S system, which was
developed at Bell Laboratories by John Chambers et al. It provides a
wide variety of statistical and graphical techniques (linear and
nonlinear modelling, statistical tests, time series analysis,
classification, clustering, ...).

%files -n R-doc-info
%_infodir/R-*.info*

%post -n R-doc-info
%install_info R-{FAQ,admin,data,exts,intro,ints,lang}.info

%preun -n R-doc-info
%uninstall_info R-{FAQ,admin,data,exts,intro,ints,lang}.info

%changelog
* Mon Feb 19 2007 Alexey Tourbin <at@altlinux.ru> 2.4.1-alt1
- 2.3.1 -> 2.4.1
- imported sources into git and adapted for gear
- split the package into subpackages: R-base, R-devel, R-tcltk,
  R-doc-html, R-doc-pdf, R-doc-info
- relocated /usr/lib/R/doc/ to /usr/share/doc/R-2.4/,
  /usr/lib/R/include/ to /usr/include/R/, /usr/lib/R/etc/ to /etc/R/;
  provided compatibility symbolic links

* Sun Jun 04 2006 Alexey Tourbin <at@altlinux.ru> 2.3.1-alt1
- 2.3.0 -> 2.3.1 
- built with gfortran
- eliminated libtool and texi2dvi copies in %Rhome/bin/

* Wed Apr 26 2006 Alexey Tourbin <at@altlinux.ru> 2.3.0-alt1
- picked up from oprphaned
- major revision, revamped specfile
- removed menu icons (icons suck)
- removed %%post doc index update (no cran packages yet)
- relocated libR.so to %_libdir, soname=libR-2.3.so.0
- built against system zlib (#8243) and bzlib (#8249)
- also built against system BLAS and LAPACK shared libraries

* Sun Aug 01 2004 Yehuda Ben-Yosef <ilar@altlinux.ru> 1.9.1-alt1
- 1.9.1

* Mon Mar 22 2004 Vitaly Lugovsky <vsl@altlinux.ru> 1.8.1-alt1
- a new version

* Thu Oct 16 2003 Vitaly Lugovsky <vsl@altlinux.ru> 1.8.0-alt1
- a new version, library path fixed.

* Mon Jun 23 2003 Yehuda Ben-Yosef <ilar@altlinux.ru> 1.7.1-alt1
- 1.7.1

* Wed Feb 26 2003 Yehuda Ben-Yosef <ilar@altlinux.ru> 1.6.2-alt1
- 1.6.2

* Mon Feb 10 2003 Yehuda Ben-Yosef <ilar@altlinux.ru> 1.6.1-alt3
- new autoreq

* Tue Dec 10 2002 Yehuda Ben-Yosef <ilar@altlinux.ru> 2:1.6.1-alt2
- Building in new perl
- New snapshot path

* Thu Nov 14 2002 Yehuda Ben-Yosef <ilar@altlinux.ru> 1.6.1-alt1
- 1.6.1

* Tue Oct 16 2002 Yehuda Ben-Yosef <ilar@altlinux.ru> 1.6.0-alt1
- 1.6.0
- gcc-3.2, automake-2.5

* Thu Jun 13 2002 Sergey Bolshakov <s.bolshakov@belcaf.com> 1.4.1-alt2
- rebuilt in new env

* Fri Mar 01 2002 Stanislav Ievlev <inger@altlinux.ru> 1.4.1-alt1
- 1.4.1

* Fri Dec 21 2001 Stanislav Ievlev <inger@altlinux.ru> 1.4.0-alt1
- 1.4.0

* Thu Oct 11 2001 Stanislav Ievlev <inger@altlinux.ru> 1.3.1-alt2
- Rebuild with new libpng

* Mon Oct 01 2001 Stanislav Ievlev <inger@altlinux.ru> 1.3.1-alt1
- 1.3.1

* Mon Jul 09 2001 Stanislav Ievlev <inger@altlinux.ru> 1.3.0-alt1
- 1.3.0

* Thu May 24 2001 Stanislav Ievlev <inger@altlinux.ru> 1.2.3-alt1
- 1.2.3. Spec cleanup.

* Tue Jan 16 2001 AEN <aen@logic.ru>
- RE adaptations

* Fri Dec 22 2000 Giuseppe Ghib? <ghibo@mandrakesoft.com> 1.2.0-4mdk
- added PDF of Reference Manual.
- added tcl, tk in BuildRequires.

* Tue Dec 19 2000 Giuseppe Ghib? <ghibo@mandrakesoft.com> 1.2.0-3mdk
- removed stdout output in post scripts.

* Tue Dec 19 2000 David BAUDENS <baudens@mandrakesoft.com> 1.2.0-2mdk
- ExcludeArch: ppc

* Tue Dec 19 2000 Giuseppe Ghib? <ghibo@mandrakesoft.com> 1.2.0-1mdk
- new fresh release.

* Tue Dec 19 2000 Giuseppe Ghib? <ghibo@mandrakesoft.com> 1.1.1-3mdk
- fixed broken macros (aargh!).

* Sun Oct 28 2000 David BAUDENS <baudens@mandrakesoft.com> 1.1.1-2mdk
- Use %%make macro
- bzip2 patch

* Fri Sep 01 2000 Giuseppe Ghib? <ghibo@mandrakesoft.com> 1.1.1-1mdk
- initial mandrake release.
- added BuildRequires.
- added -fno-fast-math, otherwise R doesn't passes the arith checks.
- switched order of make check and make pdf.

* Wed Aug 16 2000 Martyn Plummer <plummer@iarc.fr>
- R 1.1.1 released. Removed R-1.1.0-cofig.sub-alpha.patch since
  this version uses up to date config.sub.

* Fri Jun 16 2000 Martyn Plummer <plummer@iarc.fr>
- Added patch R-1.1.0-cofig.sub-alpha.patch from Naoki Takebayashi

* Thu Jun 15 2000 Martyn Plummer <plummer@iarc.fr>
- Removed dependencies on egcs egcs-g77

* Tue Feb 29 2000 Martyn Plummer <plummer@iarc.fr
- Changed the description to match
  http://developer.r-project.org/R-description-short.txt

* Mon Feb 28 2000 Martyn Plummer <plummer@iarc.fr>
- Added egcs, egcs-g77 and perl as requirements. People who want to install
  their own R packages need a working build environment.

* Fri Feb 11 2000 Martyn Plummer <plummer@iarc.fr>
- Remove latex versions of help pages, to save a bit of space.
- PDF files installed in top level doc directory.
- Included R-0.99.0-fixes patch for some serious bugs

* Tue Feb  8 2000 Martyn Plummer <plummer@iarc.fr>
- Added patch R-refman.patch which prevents building the reference manual

* Fri Feb  4 2000 Martyn Plummer <plummer@iarc.fr>
- Updated in preparation for R-0.99.0.
- Now install manual in pdf format.

* Wed Dec 15 1999 Martyn Plummer <plummer@iarc.fr>
- R-0.90.1. Removed Naoki's memory profile patch

* Fri Dec 3 1999 Tim Powers <timp@redhat.com>
- move configure into build section
- quiet scripts
- built for Powertools-6.2

* Mon Nov 29 1999 Martyn Plummer <plummer@iarc.fr>
- Added patch from Naoki to fix problem with memory profile.
  (will be folded in to next R version).

* Mon Nov 22 1999 Martyn Plummer <plummer@iarc.fr>
- R 0.90.0 Naoki's patch for FFT bug no longer necessary.
- Updated URL tag to www.r-project.org

* Thu Oct 28 1999 Martyn Plummer <plummer@iarc.fr>
- RHCN is officially dead. Changed the Packager field
  back to my name and removed the Distribution field.

* Thu Oct 14 1999 Martyn Plummer <plummer@iarc.fr>
- Set CFLAGS and FFLAGS to be RPM_OPT_FLAGS. Thanks to
  Timothy H. Keitt <keitt@nceas.ucsb.edu>
- Simplified file list.

* Fri Oct 8 1999 Martyn Plummer <plummer@iarc.fr>
- Added patch from Naoki Takebayashi to fix FFT bug on Alpha
  (also found on Sparc).

* Tue Sep 7 1999 Martyn Plummer <plummer@iarc.fr>
  [R-base-0.65.0-1]
- RHOME is now R_HOME. Changed sed scripts accordingly.
- TASKS file is no longer in file list.

